@@ -3,9 +3,9 @@ use super::*;
 #[derive(Clone, Eq)]
 pub struct Literal<T> {
     ///
-    pub(crate) value: T,
+    pub value: T,
     //
-    pub(crate) range: Option<(u32, u32)>,
+    pub range: Option<(u32, u32)>,
 }
 
 impl<T: Default> Default for Literal<T> {
@@ -36,19 +36,3 @@ impl<T: PartialEq> PartialEq for Literal<T> {
         self.value.eq(&other.value)
     }
 }
-
-impl<T> Literal<T> {
-    #[inline]
-    pub fn new(value: T, range: Option<(u32, u32)>) -> Self {
-        Self { value, range }
-    }
-    #[inline]
-    pub fn unwrap(&self) -> &T {
-        &self.value
-    }
-
-    #[inline]
-    pub fn range(&self) -> Option<(u32, u32)> {
-        self.range
-    }
-}
