@@ -1,4 +1,4 @@
-use notedown_ast::{ASTKind, ASTNode, ListView, MathNode, SmartLink, TableView, TextNode};
+use notedown_ast::{ASTKind, ASTNode, nodes::{ListView, MathNode, SmartLink, TableView, TextNode}};
 use std::mem::size_of;
 
 macro_rules! show_size {
